@@ -18,8 +18,10 @@
 
 # Imports.
 from zope.interface import Interface
+# Product Imports.
+import IZMSActionListContributor
 
-class IZMSMetacmdProvider(Interface):
+class IZMSMetacmdProvider(Interface,IZMSActionListContributor.IZMSActionListContributor):
 
   def getMetaCmdDescription(self, id=None, name=None):
     """
