@@ -46,39 +46,25 @@ import _globals
 import _mimetypes
 import _pilutil
 import _xmllib
+import _zopeutil
 
 __all__= ['ZMSGlobals']
 
 # ------------------------------------------------------------------------------
 #  MD5:
 # ------------------------------------------------------------------------------
-try: # Python >= 2.5
-  import hashlib
+import hashlib
 
-  class MD5DigestScheme:
+class MD5DigestScheme:
 
-    def encrypt(self, pw):
-      enc = hashlib.md5(pw)
-      enc = enc.hexdigest()
-      return enc
+  def encrypt(self, pw):
+    enc = hashlib.md5(pw)
+    enc = enc.hexdigest()
+    return enc
 
-    def validate(self, reference, attempt):
-      compare = self.encrypt(attempt)[:-1]
-      return (compare == reference)
-
-except: # Python < 2.5
-  import md5
-
-  class MD5DigestScheme:
-
-    def encrypt(self, pw):
-      enc = md5.new(pw)
-      enc = enc.hexdigest()
-      return enc
-
-    def validate(self, reference, attempt):
-      compare = self.encrypt(attempt)[:-1]
-      return (compare == reference)
+  def validate(self, reference, attempt):
+    compare = self.encrypt(attempt)[:-1]
+    return (compare == reference)
 
 AuthEncoding.registerScheme('MD5', MD5DigestScheme())
 
@@ -340,11 +326,15 @@ class ZMSGlobals:
     @type auth: C{string}
     @param parse_qs: Parse Query-String
     @type parse_qs: C{int}, values are 0 or 1
+    @param timeout: Time-Out [s]
+    @type timeout: C{int}, values in seconds
+    @param headers: Request-Headers
+    @type headers: C{dict}
     @return: Response-Body
     @rtype: C{string}
     """
-    def http_import(self, url, method='GET', auth=None, parse_qs=0):
-      return _globals.http_import( self, url, method, auth, parse_qs)
+    def http_import(self, url, method='GET', auth=None, parse_qs=0, timeout=10, headers={'Accept':'*/*'}):
+      return _globals.http_import( self, url, method=method, auth=auth, parse_qs=parse_qs, timeout=timeout, headers=headers)
 
 
     """
@@ -910,22 +900,27 @@ class ZMSGlobals:
       if type(i) is list or type(i) is tuple:
         return '['+','.join(map(lambda x: self.str_json(x,encoding,errors),i))+']'
       elif type(i) is dict:
-        return '{'+','.join(map(lambda x: '\'%s\':%s'%(x,self.str_json(i[x],encoding,errors)),i.keys()))+'}'
+        return '{'+','.join(map(lambda x: '"%s":%s'%(x,self.str_json(i[x],encoding,errors)),i.keys()))+'}'
       elif type(i) is time.struct_time:
         try:
-          return '\'%s\''%self.getLangFmtDate(i)
+          return '"%s"'%self.getLangFmtDate(i)
         except:
           pass
       elif type(i) is int or type(i) is float:
         return str(i)
+      elif type(i) is bool:
+        return str(i).lower()
       elif i is not None:
-        if type(i) is unicode and not (i.strip().startswith('<') and i.strip().endswith('>')):
-          import cgi
-          i = cgi.escape(i).encode(encoding, errors)
+        if type(i) is unicode:
+          if not (i.strip().startswith('<') and i.strip().endswith('>')):
+            import cgi
+            i = cgi.escape(i).encode(encoding, errors)
+          else:
+            i = i.encode(encoding, errors)
         else:
           i = str(i)
-        return '\'%s\''%(i.replace('\\','\\\\').replace('\'','\\\'').replace('\n','\\n').replace('\r','\\r'))
-      return '\'\''
+        return '"%s"'%(i.replace('\\','\\\\').replace('"','\\"').replace('\n','\\n').replace('\r','\\r'))
+      return '""'
 
 
     """
@@ -1392,7 +1387,23 @@ class ZMSGlobals:
 
     ############################################################################
     #
-    #  PLUGINS
+    #  Zope-Util
+    #
+    ############################################################################
+
+    """
+    Read Zope-object from container.
+    """
+    def readObject(self, ob, default=None):
+      data = default
+      if ob is not None:
+        data= _zopeutil.readObject(ob.aq_parent,absattr(ob.id),default)
+      return data
+
+
+    ############################################################################
+    #
+    #  Plugins
     #
     ############################################################################
 
@@ -1665,6 +1676,25 @@ class ZMSGlobals:
       except:
         return -1
 
+    """
+    Check if feature toggle is set.
+    @rtype: C{boolean}
+    """ 
+    def isFeatureEnabled(self, feature=''):
+    
+      # get conf from current client
+      confprop = self.breadcrumbs_obj_path(False)[0].getConfProperty('ZMS.Features.enabled','')
+      features = confprop.replace(',',';').split(';')
+      # get conf from top master if there is no feature toggle set at client
+      if len(features)==1 and features[0].strip()=='':
+        confprop = self.breadcrumbs_obj_path(True)[0].getConfProperty('ZMS.Features.enabled','')
+        features = confprop.replace(',',';').split(';')
+    
+      if len(filter(lambda ob: ob.strip()==feature.strip(), features))>0:
+        return True
+      else:
+        return False
+
 # call this to initialize framework classes, which
 # does the right thing with the security assertions.
 Globals.InitializeClass(ZMSGlobals)
