@@ -18,6 +18,7 @@
 
 
 # Imports.
+from Products.ExternalMethod import ExternalMethod
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.PageTemplates import ZopePageTemplate
 from Products.PythonScripts import PythonScript
@@ -26,6 +27,7 @@ import urllib
 import zope.interface
 # Product Imports.
 import _globals
+import _zopeutil
 import IZMSMetacmdProvider,IZMSConfigurationProvider
 import ZMSItem
 
@@ -106,7 +108,7 @@ class ZMSMetacmdProvider(
     # Management Permissions.
     # -----------------------
     __administratorPermissions__ = (
-		'manage_changeProperties', 'manage_main', 'manage_main_acquire'
+		'manage_changeMetacmds', 'manage_main', 'manage_main_acquire'
 		)
     __ac_permissions__=(
 		('ZMS Administrator', __administratorPermissions__),
@@ -134,14 +136,14 @@ class ZMSMetacmdProvider(
     # ------------------------------------------------------------------------------
     
     def _importXml(self, item, createIfNotExists=1):
-    
+      
       id = item['id']
       if createIfNotExists == 1:
-    
+        
         # Delete existing object.
         try: self.delMetacmd(id)
         except: pass
-    
+        
         # Initialize attributes of new object.
         newId = id
         newAcquired = 0
@@ -155,14 +157,14 @@ class ZMSMetacmdProvider(
         newRoles = item['roles']
         newNodes = item.get('nodes','{$}')
         newData = item['data']
-    
+        
         # Return with new id.
         return self.setMetacmd(None, newId, newAcquired, newName, newTitle, newMethod, \
           newData, newExec, newDescription, newIconClazz, newMetaTypes, newRoles, \
           newNodes)
 
 
-    def importXml(self, xml, REQUEST=None, createIfNotExists=1):
+    def importXml(self, xml, createIfNotExists=1):
       v = self.parseXmlString(xml)
       if type(v) is list:
         for item in v:
@@ -184,12 +186,11 @@ class ZMSMetacmdProvider(
       if len(old) > 0:
         obs.remove(old[0])
       self.commands = obs
-      # Make persistent.
-      self.commands = copy.deepcopy(self.commands)
+      self.commands = copy.deepcopy(self.commands) # Make persistent.
       
       # Remove Template.
-      home = self.aq_parent
-      home.manage_delObjects(ids=[id])
+      container = self.aq_parent
+      _zopeutil.removeObject(container,id)
       
       # Return with empty id.
       return ''
@@ -222,51 +223,32 @@ class ZMSMetacmdProvider(
       new['nodes'] = newNodes
       new['exec'] = newExec
       obs.append(new)
-      # Make persistent.
-      self.commands = copy.deepcopy(self.commands)
+      self.commands = copy.deepcopy(self.commands) # Make persistent.
       
-      # Insert Template.
-      home = self.aq_parent
-      if id is None:
-        newTitle = '*** DO NOT DELETE OR MODIFY ***'
-        if newAcquired:
-          home = self.getPortalMaster()
-          newMethod = getattr(home,newId).meta_type
-        if newId in self.objectIds():
-          home.manage_delObjects(ids=[newId])
-        if newMethod == 'DTML Method': 
-          home.manage_addDTMLMethod(newId,newTitle) 
-          if newData is None: 
-            newData = dtmlExampleCode
-        elif newMethod == 'DTML Document': 
-          home.manage_addDTMLDocument(newId,newTitle) 
-          if newData is None:
-            newData = dtmlExampleCode 
+      # Insert Object.
+      container = self.aq_parent
+      if newAcquired:
+        newMethod = getattr(self.getPortalMaster(),newId).meta_type
+        newData = ''
+      if newMethod is None:
+        newMethod = getattr(container,id).meta_type
+      newTitle = '*** DO NOT DELETE OR MODIFY ***'
+      if id is None and newData is None:
+        if newMethod in ['DTML Document','DTML Method']:
+          newData = dtmlExampleCode
         elif newMethod == 'Page Template':
-          ZopePageTemplate.manage_addPageTemplate(home,id=newId,title=newTitle)
-          if newData is None: 
-            newData = pageTemplateExampleCode 
+          newData = pageTemplateExampleCode 
         elif newMethod == 'Script (Python)':
-          PythonScript.manage_addPythonScript(home,newId)
-          if newData is None:
-            newData = pyScriptExampleCode
-      
-      # Rename Template.
-      elif id != newId:
-        home.manage_renameObject(id=id,new_id=newId)
-      
-      # Update Template.
-      ob = getattr(home,newId,None)
-      if ob is not None:
-        if newAcquired:
+          newData = pyScriptExampleCode
+        elif newMethod == 'External Method':
           newData = ''
-        if newData is not None:
-          if ob.meta_type in ['DTML Method','DTML Document']:
-            ob.manage_edit(title=ob.title,data=newData)
-          elif ob.meta_type == 'Page Template':
-            ob.pt_edit(newData,content_type=ob.content_type)
-          elif ob.meta_type == 'Script (Python)':
-            ob.write(newData)
+          newData += '# Example code:\n'
+          newData += '\n'
+          newData += 'def ' + newId + '( self):\n'
+          newData += '  return "This is the external method ' + newId + '"\n'
+      _zopeutil.removeObject(container, id)
+      _zopeutil.removeObject(container, newId)
+      _zopeutil.addObject(container, newMethod, newId, newTitle, newData)
       
       # Return with new id.
       return newId
@@ -288,17 +270,8 @@ class ZMSMetacmdProvider(
     # Returns action.
     # --------------------------------------------------------------------------
     def getMetaCmd(self, id=None, name=None):
-      obs = []
-      for x in self.commands:
-        # Acquire from parent.
-        if x.get('acquired',0)==1:
-          portalMaster = self.getPortalMaster()
-          if portalMaster is not None:
-            x = portalMaster.getMetaCmd(x['id']) 
-            x['acquired'] = 1
-        else:
-          x = x.copy()
-        obs.append(x)
+      
+      obs = self.getMetaCmds(sort=False)
       # Filter by Id.
       if id is not None:
         obs = filter(lambda x: x['id']==id, obs)
@@ -308,9 +281,26 @@ class ZMSMetacmdProvider(
       # Not found!
       if len(obs) == 0:
         return None
-      ob = obs[0]
-      ob['meta_type'] = getattr(self,ob['id']).meta_type
-      return ob
+      
+      # Refresh Object.
+      metaCmd = obs[0]
+      container = self.aq_parent
+      src = _zopeutil.getObject(metaCmd['home'],metaCmd['id'])
+      newData = _zopeutil.readObject( metaCmd['home'], metaCmd['id'],'')
+      data = _zopeutil.readObject( container,metaCmd['id'],'')
+      if src is not None and newData != data:
+        newMethod = src.meta_type
+        newId = metaCmd['id']
+        newTitle = '*** DO NOT DELETE OR MODIFY ***'
+        _zopeutil.removeObject(container, newId, removeFile=False)
+        _zopeutil.addObject(container, newMethod, newId, newTitle, newData)
+      ob = _zopeutil.getObject(container,metaCmd['id'])
+      if ob is not None:
+        metaCmd['meta_type'] = ob.meta_type
+        metaCmd['data'] = _zopeutil.readObject(container,metaCmd['id'])
+        metaCmd['bobobase_modification_time'] = ob.bobobase_modification_time().timeTime()
+      
+      return metaCmd
 
 
     # --------------------------------------------------------------------------
@@ -350,7 +340,7 @@ class ZMSMetacmdProvider(
             metaCmd['acquired'] = 1
         else:
           metaCmd = metaCmd.copy()
-          metaCmd['home'] = self
+          metaCmd['home'] = self.aq_parent
         metaCmds.append(metaCmd)
       return metaCmds
 
@@ -424,26 +414,20 @@ class ZMSMetacmdProvider(
         elif btn == self.getZMILangStr('BTN_EXPORT'):
           value = []
           ids = REQUEST.get('ids',[])
-          for metaCmd in self.getMetaCmds():
-            if metaCmd['id'] in ids or len(ids) == 0:
+          for id in self.getMetaCmdIds():
+            if id in ids or len(ids) == 0:
+              metaCmd = self.getMetaCmd(id)
               # Catalog.
               el_id = metaCmd['id']
               el_name = metaCmd['name']
               el_title = metaCmd.get('title','')
+              el_meta_type = metaCmd['meta_type']
               el_description = metaCmd['description']
               el_icon_clazz = metaCmd.get('icon_clazz','')
               el_meta_types = metaCmd['meta_types']
               el_roles = metaCmd['roles']
               el_exec = metaCmd['exec']
-              # Object.
-              ob = getattr(self,metaCmd['id'])
-              el_meta_type = ob.meta_type
-              if ob.meta_type in ['DTML Method','DTML Document']:
-                el_data = ob.raw
-              elif ob.meta_type in ['Page Template']:
-                el_data = ob.read()
-              elif ob.meta_type in ['Script (Python)']:
-                el_data = ob.body()
+              el_data = _zopeutil.readObject(metaCmd['home'],metaCmd['id'])
               # Value.
               value.append({'id':el_id,'name':el_name,'title':el_title,'description':el_description,'meta_types':el_meta_types,'roles':el_roles,'exec':el_exec,'icon_clazz':el_icon_clazz,'meta_type':el_meta_type,'data':el_data})
           # XML.
@@ -454,7 +438,6 @@ class ZMSMetacmdProvider(
             filename = 'export.metacmd.xml'
           content_type = 'text/xml; charset=utf-8'
           export = self.getXmlHeader() + self.toXmlString(value,1)
-          
           RESPONSE.setHeader('Content-Type',content_type)
           RESPONSE.setHeader('Content-Disposition','attachment;filename="%s"'%filename)
           return export
@@ -468,8 +451,7 @@ class ZMSMetacmdProvider(
             self.importXml(xml=f)
           else:
             filename = REQUEST['init']
-            createIfNotExists = 1
-            self.importConf(filename, REQUEST, createIfNotExists)
+            self.importConf(filename, createIfNotExists=1)
           message = self.getZMILangStr('MSG_IMPORTED')%('<i>%s</i>'%f.filename)
         
         # Insert.
@@ -482,7 +464,8 @@ class ZMSMetacmdProvider(
           newMethod = REQUEST.get('_type','DTML Method')
           newData = None
           newExec = REQUEST.get('_exec',0)
-          id = self.setMetacmd(None, newId, newAcquired, newName, newTitle, newMethod, newData, newExec)
+          newIconClazz = REQUEST.get('_icon_clazz','')
+          id = self.setMetacmd(None, newId, newAcquired, newName, newTitle, newMethod, newData, newExec, newIconClazz=newIconClazz)
           message = self.getZMILangStr('MSG_INSERTED')%id
         
         # Return with message.
