@@ -207,9 +207,10 @@ class ZMSMetaobjManager:
           newKeys = []
           newDefault = ''
           self.setMetaobjAttr(id,tmpltId,tmpltId,tmpltName,0,0,0, newType, newKeys, tmpltCustom, newDefault)
+      _globals.writeBlock( self, '[ZMSMetaobjManager._importMetaobjXml]: id=%s'%str(id))
       return id
 
-    def importMetaobjXml(self, xml, REQUEST=None, createIfNotExists=1, createIdsFilter=None):
+    def importMetaobjXml(self, xml, createIfNotExists=1, createIdsFilter=None):
       self.REQUEST.set( '__get_metaobjs__', True)
       ids = []
       v = self.parseXmlString( xml, mediadbStorable=False)
@@ -220,6 +221,7 @@ class ZMSMetaobjManager:
         ids.append( id)
       if len( ids) == 1:
         ids = ids[ 0]
+      _globals.writeBlock( self, '[ZMSMetaobjManager.importMetaobjXml]: ids=%s'%str(ids))
       return ids
 
     def exportMetaobjXml(self, ids, REQUEST=None, RESPONSE=None):
@@ -239,7 +241,7 @@ class ZMSMetaobjManager:
       for id in keys:
         if id in export_ids or len(export_ids) == 0:
           ob = copy.deepcopy(self.__get_metaobj__(id))
-          revision = ob.get( 'revision', revision)
+          revision = self.getMetaobjRevision(id)
           attrs = []
           for attr in ob['attrs']:
             attr_id = attr['id']
@@ -425,7 +427,28 @@ class ZMSMetaobjManager:
     #  Returns meta-object specified by id.
     # --------------------------------------------------------------------------
     def getMetaobj(self, id):
-      return _globals.nvl( self.__get_metaobj__(id), {'id':id, 'attrs':[], })
+      ob = _globals.nvl( self.__get_metaobj__(id), {'id':id, 'attrs':[], })
+      if ob is not None and ob.get('acquired',0) == 1:
+        for k in ob.keys():
+          v = self.getConfProperty('%s.%s'%(id,k),None)
+          if v is not None:
+            ob[k] = v
+      return ob
+
+
+    # --------------------------------------------------------------------------
+    #  ZMSMetaobjManager.getMetaobjRevision:
+    #
+    #  Returns meta-object-revision specified by id.
+    # --------------------------------------------------------------------------
+    def getMetaobjRevision(self, id):
+      ob = self.getMetaobj(id)
+      if ob is not None and ob.get('type') == 'ZMSPackage':
+        metaobjs = filter(lambda x:x.get('package')==ob['id'],self.__get_metaobjs__().values())
+        revision = max(['0.0.0']+map(lambda x:_globals.nvl(x.get('revision'),'0.0.0'),metaobjs))
+        if revision > ob.get('revision','0.0.0'):
+          ob['revision'] = revision
+      return ob.get('revision','0.0.0')
 
 
     # --------------------------------------------------------------------------
@@ -574,9 +597,7 @@ class ZMSMetaobjManager:
       attrs = []
       ob = self.__get_metaobj__(id)
       if ob is not None:
-        attrs = ob.get('attrs',ob.get('__obj_attrs__'))
-        if attrs is None:
-          raise zExceptions.InternalError('Can\'t getMetaobjAttrIds: %s'%(str(id)))
+        attrs = ob.get('attrs',ob.get('__obj_attrs__',[]))
         if len( types) > 0:
           attrs = filter( lambda x: x['type'] in types, attrs)
       return attrs
@@ -936,7 +957,7 @@ class ZMSMetaobjManager:
     # --------------------------------------------------------------------------
     def delMetaobjAttr(self, id, attr_id):
       ob = self.__get_metaobj__(id)
-      attrs = copy.copy(ob['attrs'])
+      attrs = copy.copy(ob.get('attrs',[]))
       
       # Delete Attribute.
       cp = []
@@ -994,32 +1015,37 @@ class ZMSMetaobjManager:
     #
     #  Change properties.
     ############################################################################
-    def manage_ajaxChangeProperties(self, id, REQUEST=None, RESPONSE=None):
+    def manage_ajaxChangeProperties(self, id, REQUEST, RESPONSE=None):
       """ MetaobjManager.manage_ajaxChangeProperties """
-      ob = self.__get_metaobj__(id)
-      RESPONSE = REQUEST.RESPONSE
-      content_type = 'text/xml; charset=utf-8'
-      filename = 'manage_ajaxChangeProperties.xml'
-      RESPONSE.setHeader('Content-Type',content_type)
-      RESPONSE.setHeader('Content-Disposition','inline;filename="%s"'%filename)
-      RESPONSE.setHeader('Cache-Control', 'no-cache')
-      RESPONSE.setHeader('Pragma', 'no-cache')
       xml = self.getXmlHeader()
       xml += '<result '
       xml += ' id="%s"'%id
+      ob = self.__get_metaobj__(id)
+      prefix = 'set'
       for key in REQUEST.form.keys():
-        if key.find('set') == 0:
-          k = key[3:].lower()
+        if key.startswith(prefix):
+          k = key[len(prefix):].lower()
           v = REQUEST.form.get(key)
           if k in ob.keys():
-            ob[k] = v
+            if ob.get('acquired'):
+              self.setConfProperty('%s.%s'%(id,k),v)
+            else:
+              ob[k] = v
             xml += ' %s="%s"'%(k,str(v))
       xml += '/>'
       # Assign Attributes to Meta-Object.
       self.model[id] = ob
       # Make persistent.
       self.model = self.model.copy()
-      return xml
+      # Return with xml
+      if RESPONSE is not None:
+        content_type = 'text/xml; charset=utf-8'
+        filename = 'manage_ajaxChangeProperties.xml'
+        RESPONSE.setHeader('Content-Type',content_type)
+        RESPONSE.setHeader('Content-Disposition','inline;filename="%s"'%filename)
+        RESPONSE.setHeader('Cache-Control', 'no-cache')
+        RESPONSE.setHeader('Pragma', 'no-cache')
+        return xml
 
 
     ############################################################################
@@ -1031,6 +1057,7 @@ class ZMSMetaobjManager:
         """ ZMSMetaobjManager.manage_changeProperties """
         old_model = copy.deepcopy(self.model)
         message = ''
+        messagekey = 'manage_tabs_message'
         extra = {}
         t0 = time.time()
         id = REQUEST.get('id','').strip()
@@ -1038,6 +1065,7 @@ class ZMSMetaobjManager:
         REQUEST.set( '__get_metaobjs__', True)
         
         try:
+          sync_id = []
           
           # Delete.
           # -------
@@ -1052,7 +1080,7 @@ class ZMSMetaobjManager:
               if metaObj['type'] == 'ZMSPackage':
                 for pkgMetaObjId in self.getMetaobjIds():
                   pkgMetaObj = self.getMetaobj( pkgMetaObjId)
-                  if pkgMetaObj[ 'package'] == metaObj[ 'id']:
+                  if pkgMetaObj.get('package') == metaObj.get('id'):
                     if pkgMetaObjId not in meta_ids:
                       meta_ids.append( pkgMetaObjId)
             for meta_id in meta_ids:
@@ -1072,15 +1100,15 @@ class ZMSMetaobjManager:
             newValue = {}
             newValue['id'] = id
             newValue['name'] = REQUEST.get('obj_name').strip()
-            newValue['revision'] = REQUEST.get('obj_revision').strip()
+            newValue['revision'] = REQUEST.get('obj_revision','').strip()
             newValue['type'] = REQUEST.get('obj_type').strip()
-            newValue['package'] = REQUEST.get('obj_package').strip()
+            newValue['package'] = REQUEST.get('obj_package','').strip()
             newValue['attrs'] = savedAttrs
             newValue['enabled'] = REQUEST.get('obj_enabled',0)
             newValue['access'] = {
-             'insert': REQUEST.get( 'access_insert', []),
+             'insert_deny': REQUEST.get( 'access_insert_deny', []),
              'insert_custom': REQUEST.get( 'access_insert_custom', ''),
-             'delete': REQUEST.get( 'access_delete', []),
+             'delete_deny': REQUEST.get( 'access_delete_deny', []),
              'delete_custom': REQUEST.get( 'access_delete_custom', ''),
             }
             self.setMetaobj( newValue)
@@ -1112,8 +1140,8 @@ class ZMSMetaobjManager:
             # Return with message.
             message += self.getZMILangStr('MSG_CHANGED')
             # Insert attribute.
-            attr_id = REQUEST['attr_id'].strip()
-            newName = REQUEST['attr_name'].strip()
+            attr_id = REQUEST.get('attr_id','').strip()
+            newName = REQUEST.get('attr_name','').strip()
             newMandatory = REQUEST.get('_mandatory',0)
             newMultilang = REQUEST.get('_multilang',0)
             newRepetitive = REQUEST.get('_repetitive',0)
@@ -1241,7 +1269,11 @@ class ZMSMetaobjManager:
                 extra['temp_import_file_id'] = temp_id
               else:
                 createIdsFilter = REQUEST.get('createIdsFilter')
-                self.importMetaobjXml(xmlfile,createIdsFilter=createIdsFilter)
+                ids = self.importMetaobjXml(xmlfile,createIdsFilter=createIdsFilter)
+                if type(ids) is list:
+                  sync_id.extend(ids)
+                else:
+                  sync_id.append(ids)
                 message = self.getZMILangStr('MSG_IMPORTED')%('<em>%s</em>'%filename)
           
           # Move to.
@@ -1253,41 +1285,34 @@ class ZMSMetaobjManager:
             message = self.getZMILangStr('MSG_MOVEDOBJTOPOS')%(("<em>%s</em>"%attr_id),(pos+1))
           
           ##### SYNCHRONIZE ####
-          sync_id = []
-          for k in self.model.keys():
-            if old_model.has_key(k):
-              d = self.model[k]
-              types = self.valid_types
-              for i in range(len(self.metas)/2):
-                  types.append(self.metas[i*2])
-              valid_types_attrs = map(lambda x: (x['id'],x), filter(lambda x: x['type'] in self.valid_types, d.get('attrs',[])))
-              valid_types_attrs.sort()
-              old_d = old_model[k]
-              old_valid_types_attrs = map(lambda x: (x['id'],x), filter(lambda x: x['type'] in self.valid_types, old_d.get('attrs',[])))
-              old_valid_types_attrs.sort()
-              if valid_types_attrs != old_valid_types_attrs:
+          types = self.valid_types+map(lambda x:self.metas[x*2],range(len(self.metas)/2))
+          for k in self.getMetaobjIds():
+            if k not in sync_id:
+              if old_model.has_key(k):
+                d = self.model[k]
+                types_attrs = map(lambda x: (x['id'],x), filter(lambda x: x['type'] in types, d.get('attrs',[])))
+                d = old_model[k]
+                old_types_attrs = map(lambda x: (x['id'],x), filter(lambda x: x['type'] in types, d.get('attrs',[])))
+                if types_attrs != old_types_attrs:
+                  sync_id.append(k)
+              else:
                 sync_id.append(k)
-            else:
-              sync_id.append(k)
-          if sync_id:
+          if len(sync_id) > 0:
             _globals.writeBlock( self, '[ZMSMetaobjManager.manage_changeProperties]: sync_id=%s'%str(sync_id))
             self.synchronizeObjAttrs( sync_id)
         
         # Handle exception.
         except:
-          _globals.writeError(self,"[manage_changeProperties]")
-          error = str( sys.exc_type)
-          if sys.exc_value:
-            error += ': ' + str( sys.exc_value)
-          target = self.url_append_params( target, { 'manage_tabs_error_message':error})
+          message = _globals.writeError(self,"[manage_changeProperties]")
+          messagekey = 'manage_tabs_error_message'
         
         # Return with message.
         if RESPONSE:
-          target = self.url_append_params( target, { 'lang':lang, 'id':id, 'attr_id':REQUEST.get('attr_id','')})
-          target = self.url_append_params( target, extra)
           if len( message) > 0:
             message += ' (in '+str(int((time.time()-t0)*100.0)/100.0)+' secs.)'
-            target = self.url_append_params( target, { 'manage_tabs_message':message})
+            target = self.url_append_params( target, { messagekey: message})
+          target = self.url_append_params( target, { 'lang': lang, 'id':id, 'attr_id':REQUEST.get('attr_id','')})
+          target = self.url_append_params( target, extra)
           if REQUEST.has_key('inp_id_name'):
             target += '&inp_id_name=%s'%REQUEST.get('inp_id_name')
             target += '&inp_name_name=%s'%REQUEST.get('inp_name_name')
