@@ -30,6 +30,7 @@ from App.ImageFile import ImageFile
 from DateTime.DateTime import DateTime
 import ConfigParser
 import OFS.misc_
+import fnmatch
 import os
 import re
 import stat
@@ -45,6 +46,7 @@ import _multilangmanager
 import _mediadb
 import _sequence
 import _zmsattributecontainer
+import ZMSFormatProvider, ZMSFormatProviderAcquired
 import ZMSMetacmdProvider, ZMSMetacmdProviderAcquired
 import ZMSWorkflowProvider, ZMSWorkflowProviderAcquired
 
@@ -106,6 +108,7 @@ def initialize(context):
         # register deprecated classes
         dummy_constructors = (zmscustom.manage_addZMSCustomForm, zmscustom.manage_addZMSCustom,)
         dummy_permission = 'Add ZMSs'
+        zms.NoETagAdapter.register()
         
         # automated registration of language-dictionary
         OFS.misc_.misc_.zms['langdict']=_multilangmanager.langdict()
@@ -123,6 +126,15 @@ def initialize(context):
             if not stat.S_ISDIR(mode):
               registerImage(filepath,file)
         
+        # automated assembly of conf-properties
+        print "automated assembly of conf-properties"
+        l = assembleConfProperties(package_home(globals()),'*.py,*.zpt')
+        d = dict((l[i],l[i+1]) for i in range(0, len(l), 2))
+        keys = d.keys()
+        keys.sort()
+        for key in keys:
+          print key,'=',d[key]
+        
         # automated minification
         confkeys = confdict.keys()
         for confkey in filter(lambda x:x.startswith('gen.') and x+'.include' in confkeys,confkeys):
@@ -281,4 +293,30 @@ def registerImage(filepath,s):
   icon.__roles__ = None
   OFS.misc_.misc_.zms[s]=icon
 
+def assembleConfProperties(path, pattern):
+  """
+  assemble conf-properties
+  """
+  l = []
+  for file in os.listdir(path):
+    filepath = path+os.sep+file
+    mode = os.stat(filepath)[stat.ST_MODE]
+    if stat.S_ISDIR(mode): 
+      l.extend(assembleConfProperties(filepath,pattern))
+    elif len(filter(lambda x:fnmatch.fnmatch(file,x),pattern.split(',')))>0:
+      f = open(filepath,'r')
+      data = f.read()
+      f.close()
+      sp = data.split('getConfProperty(')
+      if len(sp) > 1:
+        for s in sp[1:]:
+          s = s[:s.find(')')]
+          i = s.find(',')
+          k = s[:i]
+          k = k[k.find('\'')+1:k.rfind('\'')]
+          v = s[i+1:]
+          if k:
+            l.extend([k,v])
+  return l
+
 ################################################################################
