@@ -1037,6 +1037,6 @@ class MyBlobWrapper:
     """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
     __str____roles__ = None
     def __str__(self):
-      return str(self.f)
+      return self.getData()
 
 ################################################################################
\ No newline at end of file
