@@ -27,24 +27,11 @@ import _confmanager
 import _globals
 import _objattrs
 
-# ------------------------------------------------------------------------------
-#  _zreferableitem.getMedlineLink:
-# ------------------------------------------------------------------------------
-def getMedlineLink(url):
-  try:
-    http_prefix = 'http://'
-    if url.find(http_prefix) == 0:
-      url = url[len(http_prefix):]
-    url = 'http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=%i&dopt=Abstract'%int(url)
-  except:
-    pass
-  return url
-
 # ------------------------------------------------------------------------------
 #  _zreferableitem.isMailLink:
 # ------------------------------------------------------------------------------
 def isMailLink(url):
-  rtn = type(url) is str and url.lower().find('mailto:') == 0
+  rtn = type(url) is str and url.lower().startswith('mailto:')
   return rtn
 
 # ------------------------------------------------------------------------------
@@ -146,7 +133,7 @@ class ZReferableItem:
       path = ob.relative_obj_path()
       clientIds = absolute_home(ob).split('/')
       thisIds = absolute_home(self).split('/')
-      if clientIds[-1] != thisIds[-1]:
+      if self.getConfProperty('ZMS.internalLinks.home',1)==1 or clientIds[-1] != thisIds[-1]:
         if len(clientIds) <= len(thisIds):
           path = clientIds[-1] + '@' + path
         else:
@@ -457,17 +444,11 @@ class ZReferableItem:
         if i > 0:
           clientIds = path[:i].split('/')
           path = path[i+1:]
-          thisHome = self.getHome()
-          clientHome = None
-          if thisHome.aq_parent.id == clientIds[-1]:
-            clientHome = thisHome
-            for j in range(len(clientIds)):
-              if clientHome.aq_parent.id == clientIds[-(j+1)]:
-                clientHome = clientHome.aq_parent
-          elif hasattr(thisHome,clientIds[0]):
-            clientHome = thisHome
-            for j in range(len(clientIds)):
-              clientHome = getattr(clientHome,clientIds[j],None)
+          clientHome = self.getHome()
+          for clientId in clientIds:
+            clientHome = getattr(clientHome,clientId,None)
+            if clientHome is None:
+              break
           if clientHome is not None:
             obs = clientHome.objectValues(['ZMS'])
             if obs:
@@ -503,32 +484,16 @@ class ZReferableItem:
       return prefix + self.encrypt_ordtype(url[len(prefix):])
     return url
 
-
   # ----------------------------------------------------------------------------
-  #  ZReferableItem.getLinkHtml:
-  #
-  #  Resolves internal/external links and returns Html.
+  #  ZReferableItem.tal_anchor:
+  #  
+  #  @param
+  #  @return
   # ----------------------------------------------------------------------------
-  def getLinkHtml( self, url, html='<a href="%s">&raquo;</a>', REQUEST=None):
-    REQUEST = _globals.nvl( REQUEST, self.REQUEST)
-    s = ''
-    ob = self
-    while ob is not None:
-      if html in ob.getMetaobjIds( sort=0):
-        metaObj = ob.getMetaobj( html)
-        metaObjAttr = ob.getMetaobjAttr( metaObj['id'], 'getLinkHtml',syncTypes=['*'])
-        if type(metaObjAttr) is dict:
-          REQUEST.set( 'ref_id', url)
-          return self.dt_exec( metaObjAttr['custom'])
-      ob = self.getPortalMaster()
-    ob = self.getLinkObj(url,REQUEST)
-    if ob is not None:
-      if ob.isActive(REQUEST) and \
-         ob.isVisible(REQUEST):
-        url = ob.getHref2IndexHtml(REQUEST)
-        s = html%url
-    return s
-
+  def tal_anchor(self, href, target='', attrs={}, content=''):
+    filtered_attrs_keys = filter(lambda x: len(x)>0, attrs.keys())
+    str_attrs = ' '.join( map(lambda x:str(x)+'=\042'+str(attrs[x]+'\042'), filtered_attrs_keys) )
+    return '<a href="%s" %s%s>%s</a>'%(href,['',' target="%s"'%target][int(len(target)>0)],str_attrs,content)
 
   # ----------------------------------------------------------------------------
   #  ZReferableItem.synchronizeRefs:
