@@ -139,14 +139,14 @@ $(function(){
 		});
 
 	// Sortable
-	$("ul.zmi-container.zmi-sortable img.grippy").mouseover(function() {
+	$("ul.zmi-container.zmi-sortable div.grippy").mouseover(function() {
 		if (typeof self.zmiUlSortableInitialized == "undefined") {
 			self.zmiUlSortableInitialized = true;
 			pluginUI("ul.zmi-container.zmi-sortable",function() {
 				$("ul.zmi-container.zmi-sortable").sortable({
 					delay:500,
 					forcePlaceholderSize:true,
-					handle:'img.grippy',
+					handle:'div.grippy',
 					placeholder: "ui-state-highlight",
 					revert: true,
 					start: function(event, ui) {
@@ -349,8 +349,9 @@ ZMI.prototype.initInputFields = function(container) {
 				var b = true;
 				var context = this;
 				// Button
-				if(self.btnClicked==getZMILangStr("BTN_BACK") ||
-						self.btnClicked==getZMILangStr("BTN_CANCEL")) {
+				if( self.btnClicked==getZMILangStr("BTN_BACK") ||
+						self.btnClicked==getZMILangStr("BTN_CANCEL") ||
+						self.btnClicked==getZMILangStr("BTN_DELETE") ) {
 					return b;
 				}
 				// Richedit
@@ -846,30 +847,6 @@ ZMIActionList.prototype.over = function(el, evt, e) {
 				if (opticon.indexOf('<')!=0) {
 					opticon = $ZMI.icon(opticon);
 				}
-				else if (optvalue.indexOf('manage_del') >= 0 || optvalue.indexOf('manage_erase') >= 0) {
-					opticon = $ZMI.icon("icon-trash");
-				}
-				else if (optvalue.indexOf('manage_main') >= 0) {
-					opticon = $ZMI.icon("icon-edit");
-				}
-				else if (optvalue.indexOf('manage_undo') >= 0) {
-					opticon = $ZMI.icon("icon-undo");
-				}
-				else if (optvalue.indexOf('manage_cut') >= 0) {
-					opticon = $ZMI.icon("icon-cut");
-				}
-				else if (optvalue.indexOf('manage_copy') >= 0) {
-					opticon = $ZMI.icon("icon-copy");
-				}
-				else if (optvalue.indexOf('manage_paste') >= 0) {
-					opticon = $ZMI.icon("icon-paste");
-				}
-				else if (optvalue.indexOf('manage_moveObjUp') >= 0) {
-					opticon = $ZMI.icon("icon-sort-up");
-				}
-				else if (optvalue.indexOf('manage_moveObjDown') >= 0) {
-					opticon = $ZMI.icon("icon-sort-down");
-				}
 				var html = '';
 				html += '<li title="'+opttitle+'">'
 				html += '<a href="javascript:$ZMI.actionList.exec($(\'li.zmi-item' + (id==''?':first':'#zmi_item_'+id) + '\'),\'' + optlabel + '\',\'' + optvalue + '\')">';
@@ -931,7 +908,10 @@ ZMIActionList.prototype.exec = function(sender, label, target) {
 				open:function(event,ui) {
 					$ZMI.runReady();
 					$('#addInsertBtn').click(function() {
-								$("form.form-horizontal").append('<input type="hidden" name="btn" value="'+getZMILangStr('BTN_INSERT')+'">').submit();
+								var $fm = $("form.form-horizontal");
+								$("input[name=btn]:hidden",$fm).remove();
+								$fm.append('<input type="hidden" name="btn" value="'+getZMILangStr('BTN_INSERT')+'">');
+								$fm.submit();
 							});
 					$('#addCancelBtn').click(function() {
 								zmiModal("hide");
@@ -1210,10 +1190,10 @@ function tagSelected(tag, leftDelimiter, rightDelimiter) {
 	$ZMI.writeDebug("[tagSelected]: tagAttrs='"+tagAttrs+"'");
 	if (tagName == 'a' && tagAttrs == '') {
 		if (range.indexOf("@") > 0) {
-			tagAttrs = 'href="mailto:'+range+'"';
+			tagAttrs = ' href="mailto:'+range+'"';
 		}
 		else if (range.indexOf("://") > 0) {
-			tagAttrs = 'href="'+range+'" target="_blank"';
+			tagAttrs = ' href="'+range+'" target="_blank"';
 		}
 	}
 	if (tagName == 'a' && tagAttrs == '') {
@@ -1270,6 +1250,11 @@ function storeCaret(input) {
 
 function zmiRecordSetMoveRow(context, qIndex, delta) {
 	var $form = $(context).closest('form');
+	if (typeof qIndex != "undefined") {
+		var $btnGroup = $(context).closest('.btn-group');
+		var $input = $("input:checkbox:first",$btnGroup);
+		$form.append('<input type="hidden" name="qindex:int" value="' + $input.val() + '">');
+	}
 	$form.append('<input type="hidden" name="pos:int" value="' + (qIndex+1) + '">');
 	$form.append('<input type="hidden" name="newpos:int" value="' + (qIndex+1+delta) + '">');
 	$('input[name="action"]',$form).val('move');
@@ -1279,7 +1264,8 @@ function zmiRecordSetMoveRow(context, qIndex, delta) {
 function zmiRecordSetDeleteRow(context, qIndex) {
 	var $form = $(context).closest('form');
 	if (typeof qIndex != "undefined") {
-		var $input = $('input[value="'+qIndex+'"]',$form);
+		var $btnGroup = $(context).closest('.btn-group');
+		var $input = $("input:checkbox:first",$btnGroup);
 		$input.prop('checked',true).change();
 	}
 	if (confirm(getZMILangStr('MSG_CONFIRM_DELOBJ'))) {
