@@ -37,6 +37,7 @@ import _enummanager
 import _fileutil
 import _globals
 import _importable
+import _mediadb
 import _objattrs
 import _xmllib
 import _zcatalogmanager
@@ -166,10 +167,9 @@ def recurse_updateVersionBuild(docElmnt, self, REQUEST):
 # ------------------------------------------------------------------------------
 def recurse_updateVersionPatch(docElmnt, self, REQUEST):
   message = ''
-  # _confmanager.updateConf(self,REQUEST)
+  # _confmanager.updateConf(self)
   # self.getSequence()
   # self.synchronizeObjAttrs()
-  # self.initRoleDefs()
   return message
 
 
@@ -244,10 +244,10 @@ def initZMS(self, id, titlealt, title, lang, manage_lang, REQUEST):
   obj.recreateCatalog(lang)
 
   ### Init ZMS object-model.
-  _confmanager.initConf(obj, 'zms', REQUEST)
+  _confmanager.initConf(obj, 'zms')
 
   ### Init default-configuration.
-  _confmanager.initConf(obj, 'default', REQUEST)
+  _confmanager.initConf(obj, 'default')
 
   ### Init Role-Definitions and Permission Settings.
   obj.initRoleDefs()
@@ -288,12 +288,6 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
 
     ##### Add Theme ####
     homeElmnt = initTheme(self,REQUEST['theme'],REQUEST['folder_id'],REQUEST)
-    if REQUEST.get('mobile',0)==1:
-      tempId = 'myZMSmobile'
-      tempMobile = initTheme(homeElmnt,'myZMSmobile.zexp',tempId,REQUEST)
-      cb_copy_data = tempMobile.manage_cutObjects(tempMobile.objectIds())
-      homeElmnt.manage_pasteObjects(cb_copy_data=cb_copy_data)
-      homeElmnt.manage_delObjects(ids=[tempId])
 
     ##### Add ZMS ####
     titlealt = 'ZMS home'
@@ -308,44 +302,25 @@ def manage_addZMS(self, lang, manage_lang, REQUEST, RESPONSE):
 
     ##### Configuration ####
 
+    #-- Index
+    if REQUEST.get('specobj_index',0) == 1:
+      # Init configuration.
+      _confmanager.initConf(obj, 'com.zms.index')
+
     #-- QUnit
     if REQUEST.get('specobj_qunit',0) == 1:
       # Init configuration.
-      _confmanager.initConf(obj, 'com.zms.test', REQUEST)
+      _confmanager.initConf(obj, 'com.zms.test')
       # Init content.
       initContent(obj,'com.zms.test.content.xml',REQUEST)
 
     #-- Galleria
     if REQUEST.get('specobj_galleria',0) == 1:
       # Init configuration.
-      _confmanager.initConf(obj, 'com.zms.jquery.galleria', REQUEST)
+      _confmanager.initConf(obj, 'com.zms.jquery.galleria')
       # Init content.
       initContent(obj,'com.zms.jquery.galleria.content.zip',REQUEST)
 
-    #-- Example Database
-    if REQUEST.get('specobj_exampledb',0) == 1:
-      # Init configuration.
-      _confmanager.initConf(obj, 'exampledb', REQUEST)
-      # Init content.
-      initContent(obj,'exampledb.content.xml',REQUEST)
-
-    #-- Bulletin Board
-    if REQUEST.get('specobj_discussions',0) == 1:
-      # Init configuration.
-      _confmanager.initConf(obj, 'discussions', REQUEST)
-      # Init content.
-      initContent(obj,'discussions.content.xml',REQUEST)
-
-    #-- Newsletter
-    if REQUEST.get('specobj_newsletter',0) == 1:
-      # Init configuration.
-      _confmanager.initConf(obj, 'newsletter', REQUEST)
-
-    #-- Calendar
-    if REQUEST.get('specobj_calendar',0) == 1:
-      # Init configuration.
-      _confmanager.initConf(obj, 'calendar', REQUEST)
-
     ##### Access ####
     obj.synchronizePublicAccess()
 
@@ -427,7 +402,7 @@ class ZMS(
         'manage_importexport', 'manage_import', 'manage_export',
         )
     __userAdministratorPermissions__ = (
-        'manage_users', 'manage_userProperties', 'manage_roleProperties', 'userdefined_roles',
+        'manage_users', 'manage_users_sitemap', 'manage_userProperties', 'manage_roleProperties', 'userdefined_roles',
         )
     __ac_permissions__=(
         ('ZMS Administrator', __administratorPermissions__),
@@ -505,26 +480,95 @@ class ZMS(
       return initZMS(container, id, titlealt, title, lang, manage_lang, REQUEST)
 
 
+    # --------------------------------------------------------------------------
+    #  ZMS.manage_addMediaDb:
+    # --------------------------------------------------------------------------
+    def manage_addMediaDb(self, location, REQUEST=None, RESPONSE=None):
+      _mediadb.manage_addMediaDb(self, location, REQUEST, RESPONSE)
+
+
     # --------------------------------------------------------------------------
     #  ZMS.zms_version:
     #
     #  Get version.
     # --------------------------------------------------------------------------
     def zms_version(self):
-      file = open(_fileutil.getOSPath(package_home(globals())+'/version.txt'),'r')
-      rtn = file.read()
+      """
+      Try to obtain the version from package info if installed by pip
+      otherwise read from version.txt and from svnversion
+        
+        1. installed by pip from PyPI
+          (revision 'XXXX' in version.txt - package info of official releases does not contain revision)
+        2. installed by pip from ZMSLabs w/ info by svn
+          (revision 'svn-rXXXX' in package info due to setup.cfg)
+        3. installed by pip from TAR-Ball w/o info by svn
+          (revision 'XXXX' in version.txt due to nightly build - 'svn0' in package info due to setup.cfg)
+        4. deployed to instance/Products
+          (revision 'XXXX' in version.txt, maybe installed but unused package)
+        5. checked out to instance/Products as working copy from svn 
+          (revision 'REV' in version.txt, maybe installed but unused package)
+      """
+      from pkg_resources import WorkingSet, Requirement
+      zms = WorkingSet().find(Requirement.parse('ZMS3'))
+      pth = _fileutil.getOSPath(package_home(globals()))
+      
+      file = open(_fileutil.getOSPath(pth+'/version.txt'),'r')
+      version_txt = file.read()
+      version     = version_txt.strip().split('.')
       file.close()
-      return rtn
+      
+      # return plain version info if it is a deployment specific format like 
+      # ZMS3-3.Y.Z.XXXX.prj-ABCD
+      if len(version)!=4:
+        return version_txt
+      
+      # obtain revision and return formatted version info
+      # ZMS3-3.Y.Z.XXXX
+      else:
+        revision = version.pop()
+        # get revision from pip if running as package
+        if (zms is not None) and ('site-packages' in pth):
+          version_pip = str(zms.version)
+          if ('.svn-r' in version_pip):
+            # leave -r in revision to recognize as snapshot below
+            revision = version_pip.strip().split('.svn',1)[1]        
+        # get revision from svnversion
+        elif (revision == 'REV'):
+          import subprocess
+          version_svn = subprocess.Popen("svnversion",
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+            shell=True, cwd=pth, universal_newlines=True)
+          revision = version_svn.communicate()[0].strip()
+        # format revision info
+        if (revision.startswith('export')):
+          revision = ' (unknown build/snapshot)'
+        # at moment there are 4-digits for builds 
+        elif len(revision)==4:
+          revision = ' (build #%s)'%revision
+        # otherwise it is a development snapshot
+        else:
+          revision = ' (snapshot #%s)'%revision.replace('-r','')
+      
+      return '.'.join(version)+revision
 
     # --------------------------------------------------------------------------
     #  ZMS.getDocumentElement
     # --------------------------------------------------------------------------
     """
-    The root element of the site.
+    The document-element of the site.
     """
     def getDocumentElement(self):
       return self
 
+    # --------------------------------------------------------------------------
+    #  ZMS.getRootElement
+    # --------------------------------------------------------------------------
+    """
+    The root element of the site.
+    """
+    def getRootElement(self):
+      return self.breadcrumbs_obj_path()[0]
+
     # --------------------------------------------------------------------------
     #  ZMS.getAbsoluteHome
     # --------------------------------------------------------------------------
@@ -684,3 +728,37 @@ class ZMS(
       self.oParent = None
 
 ################################################################################
+
+
+# Workaround for an incompatibility with zope.browserresource 3.11.0 and newer
+# which requires an ETagAdapter to be provided by the application.
+# Sent a patch upstream to lift this requirement, at which point this
+# workaround could be removed:
+#  https://github.com/zopefoundation/zope.browserresource/pull/1
+try:
+    from zope.browserresource.interfaces import IFileResource, IETag
+    from zope.publisher.interfaces.browser import IBrowserRequest
+    from zope.interface import implementer
+
+    from zope.component import adapter, provideAdapter
+
+    @adapter(IFileResource, IBrowserRequest)
+    @implementer(IETag)
+    class NoETagAdapter(object):
+
+        def __init__(self, context, request):
+            pass
+
+        def __call__(self, mtime, content):
+            return None
+
+        @classmethod
+        def register(cls):
+            provideAdapter(cls)
+
+except ImportError:
+    # zope.browserresource before 3.11.0
+    class NoETagAdapter(object):
+        @classmethod
+        def register(cls):
+            pass
