@@ -764,7 +764,7 @@ class ZMSObject(ZMSItem.ZMSItem,
       declId = ''
       try:
         if self.getConfProperty( 'ZMS.pathhandler', 0) != 0:
-          obj_attrs_keys = self.getObjAttrs().keys()
+          obj_attrs_keys = self.getMetaobjAttrIds(self.meta_id)
           for key in [ 'attr_dc_identifier_doi', 'attr_dc_identifier_url_node']:
             if key in obj_attrs_keys:
               declId = self.getObjProperty( key, REQUEST)
@@ -931,11 +931,24 @@ class ZMSObject(ZMSItem.ZMSItem,
 
 
     # --------------------------------------------------------------------------
-    #  ZMSObject.isAnchestor:
+    #  ZMSObject.isChild:
     #
-    #  True if self is anchestor of given object.
+    #  True if self is child of given object.
     # --------------------------------------------------------------------------
-    def isAnchestor(self, ob):
+    def isChild(self, ob):
+      if ob is not None:
+        path = '/'.join(self.getPhysicalPath())
+        obPath = '/'.join(ob.getPhysicalPath())
+        return path.startswith(obPath)
+      return False
+
+
+    # --------------------------------------------------------------------------
+    #  ZMSObject.isAncestor:
+    #
+    #  True if self is ancestor of given object.
+    # --------------------------------------------------------------------------
+    def isAncestor(self, ob):
       if ob is not None:
         path = '/'.join(self.getPhysicalPath())
         obPath = '/'.join(ob.getPhysicalPath())
@@ -1004,6 +1017,7 @@ class ZMSObject(ZMSItem.ZMSItem,
     security.declareProtected('View', 'ajaxGetNode')
     def ajaxGetNode(self, lang, xml_header=True, meta_types=None, REQUEST=None):
       """ ZMSObject.ajaxGetNode """
+      # print "ajaxGetNode",self
       
       #-- Build xml.
       xml = ''
@@ -1022,7 +1036,7 @@ class ZMSObject(ZMSItem.ZMSItem,
       xml += " physical_path=\"%s\""%('/'.join(self.getPhysicalPath()))
       xml += " access=\"%s\""%str(int(self.hasAccess(REQUEST)))
       xml += " active=\"%s\""%str(int(self.isActive(REQUEST)))
-      xml += " display_icon=\"%s\""%str(self.display_icon(REQUEST)).replace('"','&quot;').replace('<','&lt;')
+      xml += " display_icon=\"%s\""%unicode(self.display_icon(REQUEST)).encode('utf8').replace('"','&quot;').replace('<','&lt;')
       xml += " display_type=\"%s\""%str(self.display_type(REQUEST))
       xml += " id=\"%s_%s\""%(self.getHome().id,self.id)
       xml += " home_id=\"%s\""%(self.getHome().id)
@@ -1306,7 +1320,15 @@ class ZMSObject(ZMSItem.ZMSItem,
       html = ''
       try:
         if self.getType() in [ 'ZMSDocument', 'ZMSResource', 'ZMSReference']:
-          html = self._getBodyContentContentEditable(self.getTitlealt(REQUEST))
+          if self.meta_id in [ 'ZMS', 'ZMSFolder', 'ZMSDocument'] and (self.getLevel()==0 or self.id in REQUEST['URL']):
+            html = '<h1>'
+            html += self.getTitle(REQUEST)
+            if self.getDCDescription(REQUEST):
+              html += '<small>%s</small></h1>'%(self.getDCDescription(REQUEST))
+            html+= '</h1>'
+          else:
+            html = self.getTitlealt(REQUEST)
+          html = self._getBodyContentContentEditable(html)
         elif 'renderShort' in self.getMetaobjAttrIds(self.meta_id):
           html = self._getBodyContentContentEditable(self.attr('renderShort'))
         else:
